using System.Collections.Generic;
using UnityEditor;
using UnityEngine;

namespace VertexColor.ScenePartition.Editor
{
    public class ScenePartitionEditorWindow : EditorWindow
    {
        private const int cellSize = 10;

        private Vector2 scrollPos = Vector2.zero;

        [MenuItem("Max/ScenePartitionWindow")]
        public static void ShowExample()
        {
            ScenePartitionEditorWindow window = GetWindow<ScenePartitionEditorWindow>();
            window.titleContent = new GUIContent($"{nameof(ScenePartitionEditorWindow)}");
        }

        private void OnGUI()
        {
            if (GUILayout.Button("Save"))
            {
                ScenePartitionSS.Save();
            }

            DrawSceneDataCache();
        }

        private void DrawSceneDataCache()
        {
            using (EditorGUILayout.ScrollViewScope scope = new EditorGUILayout.ScrollViewScope(scrollPos))
            {
                scrollPos = scope.scrollPosition;

                using (new EditorGUI.DisabledGroupScope(true))
                {
                    ScenePartitionSS scenePartitionSS = ScenePartitionSS.instance;

                    foreach (KeyValuePair<ScenePartitionSO, ScenePartitionData> sceneData in scenePartitionSS.SceneDataCache)
                    {
                        EditorGUILayout.LabelField($"{sceneData.Key.name}");

                        if (sceneData.Value.HasCreatedPartitions)
                        {
                            EditorGUILayout.LabelField($"scenePartitions");

                            foreach (KeyValuePair<uint, ScenePartition> scenePartition in sceneData.Value.ScenePartitions)
                            {
                                EditorGUILayout.IntField((int)scenePartition.Value.id);
                            }
                        }

                        EditorGUILayout.Space();

                        if (sceneData.Value.HasLoadedPartitions)
                        {
                            EditorGUILayout.LabelField($"loadedScenePartitions");

                            foreach (KeyValuePair<uint, ScenePartition> scenePartition in sceneData.Value.LoadedScenePartitions)
                            {
                                EditorGUILayout.IntField((int)scenePartition.Value.id);
                            }
                        }

                        if (sceneData.Value.SceneGrid != null)
                        {
                            EditorGUILayout.LabelField($"generatedSceneGrid");

                            foreach (KeyValuePair<int, List<uint>> item in sceneData.Value.SceneGrid.Grid)
                            {
                                EditorGUILayout.IntField("gridId", item.Key);

                                EditorGUI.indentLevel++;

                                foreach (uint id in item.Value)
                                {
                                    EditorGUILayout.IntField((int)id);
                                }

                                EditorGUI.indentLevel--;
                            }
                        }
                    }
                }
            }
        }
    }
}