using System.Collections.Generic;
using UnityEngine;

namespace VertexColor.ScenePartition.Editor
{
    [System.Serializable]
    public class SceneGrid
    {
        [SerializeField]
        private int cellSize = 10;

        [SerializeField]
        private SceneGridDictionary grid = new SceneGridDictionary();

        public SceneGridDictionary Grid => grid;

        public void Insert(uint id, Vector3 point)
        {
            int gridId = CalculateGridPosition(point, cellSize);
            if (grid.TryGetValue(gridId, out List<uint> ids))
            {
                ids.Add(id);
            }
            else
            {
                grid.Add(gridId, new List<uint> { id });
            }
        }

        public static int CalculateGridPosition(Vector3 point, int cellSize)
        {
            int x = Mathf.FloorToInt(point.x / cellSize);
            int z = Mathf.FloorToInt(point.z / cellSize);

            return IntPairToInt(x, z);
        }

        public static int IntPairToInt(int x, int y)
        {
            // Combine x and y components into a single int
            return (x << 16) | (ushort)y;
        }

        public static (int, int) IntToIntPair(int value)
        {
            // Extract x and y components from the combined int
            int x = value >> 16;
            int y = (short)value;

            return (x, y);
        }
    }
}
